@@ -103,15 +103,6 @@ def template_context(pytestconfig):
     return pytestconfig.template_context
 
 
-@pytest.fixture(scope="function")
-def function_context(pytestconfig):
-    """Report template context for the current function."""
-    if hasattr(pytestconfig, "_reporter"):
-        return pytestconfig._reporter._active_test
-    else:
-        return {}
-
-
 class ReportGenerator:
     def __init__(self, config):
         self.config = config
@@ -174,7 +165,7 @@ class ReportGenerator:
         self.context["tests"].append(testrun)
         del self._active_tests[nodeid]
 
-    def pytest_warning_captured(self, warning_message):
+    def pytest_warning_recorded(self, warning_message):
         self.context["warnings"].append(warning_message)
 
     def pytest_sessionfinish(self, session):
